importFrom("ggplot2",
           "aes", "after_stat", "annotate", "element_blank", "element_text", "facet_grid",
           "facet_wrap", "geom_blank", "geom_density", "geom_histogram","geom_hline", "geom_label", "geom_line",
           "geom_point", "geom_smooth", "geom_violin", "geom_vline","ggplot", "ggplot_build", "guides", "labs",
           "layer_data", "position_jitter", "position_nudge", "scale_color_steps2",
           "scale_x_continuous", "scale_y_continuous", "stat_density", "stat_summary", "theme",
           "theme_bw", "vars", "xlim",".data")
importFrom("stats",
           "aggregate", "ave", "bartlett.test", "cor",
           "dnorm", "fligner.test", "p.adjust", "pairwise.t.test",
           "pairwise.wilcox.test", "pt", "qt", "quantile", "reshape",
           "sd", "setNames", "shapiro.test", "median")
importFrom("utils",
           "combn", "hasName", "read.table", "write.csv")
importFrom("grid",
           "unit")
importFrom("dplyr",
           "mutate_all", "mutate_if")
importFrom("tools",
           "file_path_sans_ext")
importFrom("tibble",
           "enframe")
importFrom("tidyr",
           "separate")
importFrom("magrittr", "%>%")
import("ape")

export("get_gower_dist", "get_sil_widths", "make_clusters", "cluster_to_nexus", "write_partitioned_alignments", "write_partitioned_alignments2",
       "get_clockrate_table_BEAST2", "get_clockrate_table_MrBayes", "clockrate_summary", "clockrate_dens_plot", "clockrate_reg_plot",
       "clock_reshape", "plot_back_rates","get_pwt_rates_MrBayes", "get_pwt_rates_BEAST2", "plot_treerates_sgn",
       "combine_log", "FBD_summary", "FBD_dens_plot", "FBD_tests1", "FBD_tests2", "FBD_normality_plot", "FBD_reshape",
       "drop.dummy.beast", "drop.dummy.mb", "offset.to.dummy", "write.beast.treedata", "offset.to.dummy.metadata",
       "clade_membership")

S3method("plot", "sil_width_df")
S3method("plot", "cluster_df")
